@@ -10,7 +10,7 @@ use Carp;
 
 
 
-our $VERSION = "0.021";
+our $VERSION = "0.022";
 
 use Text::Layout::FontDescriptor;
 
@@ -97,6 +97,12 @@ sub new {
     return $self;
 }
 
+sub reset {
+    my ( $self ) = @_;
+    %fonts = ();
+    @dirs = ();
+}
+
 =over
 
 =item register_fonts( $font, $family, $style [ , $weight ] [ , $props ] )
